@@ -1,3 +1,19 @@
+# Copyright (C) 2021 Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include unitizer.R
 #' @include conditions.R
 #' @include browse.struct.R
@@ -92,6 +108,9 @@ setMethod(
     # Browse through tests that require user input, repeat so we give the user
     # an opportunity to adjust decisions before committing
 
+    old.warn <- getOption('warn')
+    on.exit(options(warn=old.warn))
+
     quit.time <- getOption("unitizer.prompt.b4.quit.time")
     if(is.null(quit.time)) quit.time <- 10
     update <- FALSE
@@ -760,8 +779,8 @@ setMethod("reviewNext", c("unitizerBrowse"),
       } else if (out.std || out.err) cat("\n")
     }
     # Need to add ignored tests as default action is N, though note that ignored
-    # tests are treated specially in `healEnvs` and are either included or removed
-    # based on what happens to the subsequent non-ignored test.
+    # tests are treated specially in `healEnvs` and are either included or
+    # removed based on what happens to the subsequent non-ignored test.
 
     if(!x@inspect.all) {
       if(
@@ -807,6 +826,8 @@ setMethod("reviewNext", c("unitizerBrowse"),
     env.sec <- if(!is.null(item.new) && !is.null(item.ref))
       item.ref@env else NULL
     assign("ls", unitizer_ls, base.env.pri)
+    assign(".traceback", unitizer_dottraceback, base.env.pri)
+    assign("traceback", unitizer_traceback, base.env.pri)
     if(!is.null(env.sec)) {
       assign("ref", function(x) eval(substitute(x), env.sec), base.env.pri)
     } else {
@@ -908,7 +929,7 @@ setMethod("reviewNext", c("unitizerBrowse"),
             browse.env1=browse.eval.env,
             browse.env2=new.env(parent=parent.env(base.env.pri)),
             valid.opts=valid.opts,
-            help=help.prompt, help.opts=help.opts
+            help=help.prompt, help.opts=help.opts, warn.sticky=TRUE
           ),
           "unitizerBrowse"
         )
