@@ -1,3 +1,19 @@
+# Copyright (C) 2021 Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' @include item.R
 
 NULL
@@ -43,7 +59,9 @@ setMethod("sizeUntz", "unitizer",
 #' Currently we only define a method for \code{unitizerItems-class} objects
 #' @keywords internal
 
-setGeneric("flattenUntz", function(x, ...) StandardGeneric("flattenUntz"))
+setGeneric(  # nocov start
+  "flattenUntz", function(x, ...) StandardGeneric("flattenUntz")
+)            # nocov end
 setMethod(
   "flattenUntz", "unitizerItems",
   function(x, ...) {
@@ -70,7 +88,7 @@ setMethod(
 
 sizeRDS <- function(object) {
   f <- tempfile()
-  if(inherits(try(saveRDS(object, f)), "try-error")) return(NA)
+  if(inherits(try(saveRDS(object, f, version=2)), "try-error")) return(NA)
   size <- file.info(f)$size
   unlink(f)
   size
