@@ -1,7 +1,24 @@
+# Copyright (C) 2021 Brodie Gaslam
+# 
+# This file is part of "unitizer"
+# 
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+# 
+# Go to <https://www.r-project.org/Licenses/GPL-2> for a copy of the license.
+
 #' Unitize an R Test Script
 #'
 #' Turn standard R scripts into unit tests by storing the expressions therein
-#' along with the results of their evaluation.
+#' along with the results of their evaluation, and provides an interactive
+#' prompt to review tests.
 #'
 #' \code{unitize} creates unit tests from a single R file, and
 #' \code{unitize_dir} creates tests from all the R files in the specified
@@ -14,7 +31,8 @@
 #' name and location, but you can specify your own location as an id, or even
 #' use a completely different mechanism to store the \code{unitizer} data by
 #' implementing S3 methods for \code{\link{get_unitizer}} and
-#' \code{\link{set_unitizer}}.
+#' \code{\link{set_unitizer}}.  For more details about storage see those
+#' functions.
 #'
 #' \code{review} allows you to review existing \code{unitizer}s and modify them
 #' by dropping tests from them.  Tests are not evaluated in this mode; you are
@@ -23,14 +41,51 @@
 #' browsing environments, unlike with \code{unitize} or \code{unitize_dir}
 #' (see \code{state} parameter).
 #'
-#' You are strongly encouraged to read through \code{vignette("unitizer")}
-#' for details and examples.  The demo (\code{demo("unitizer")}) is also a
-#' good introduction to these functions.
+#' You are strongly encouraged to read through the vignettes
+#' for details and examples (\code{browseVignettes("unitizer")}).  The demo
+#' (\code{demo("unitizer")}) is also a good introduction to these functions.
+#'
+#' @section Note:
+#'
+#' \code{unitizer} approximates the semantics of sourcing an R file when running
+#' tests, and those of the interactive prompt when reviewing them.  The
+#' semantics are not identical, and in some cases you may notice differences.
+#' For example, when running tests:
+#'
+#' \itemize{
+#'   \item All expressions are run with \code{options(warn=1)},
+#'     irrespective of what the user sets that option to.
+#'   \item \code{on.exit(...)} expressions will be evaluated immediately for
+#'     top-level statements (either in the test file or in an
+#'     \code{\link{unitizer_sect}}, thereby defeating their purpose).
+#'   \item Each test expression is run in its own environment, which is enclosed
+#'     by that of previous tests.
+#'   \item Output and Message streams are sunk so any attempt to debug directly
+#'     will be near-impossible as you won't see anything.
+#' }
+#'
+#' When reviewing them:
+#'
+#' \itemize{
+#'   \item \code{ls()} and \code{q()} are over-ridden by \code{unitizer} utility
+#'     functions.
+#'   \item Expressions are evaluated with \code{options(warn=1)} or greater,
+#'     although unlike in test running it is possible to set and keep
+#'     \code{options(warn=2)}.
+#'   \item Some single upper case letters will be interpreted as \code{unitizer}
+#'     meta-commands.
+#' }
+#'
+#' For a more complete discussion of these differences see the introductory
+#' vignette (\code{vignette('u1_intro')}), the "Special Semantics" section of
+#' the tests vignette (\code{vignette('u2_tests')}), and the "Evaluating
+#' Expressions at the \code{unitizer} Prompt" section of the interactive
+#' environment vignette (\code{vignette('u3_interactive-env')}).
 #'
 #' @section Default Settings:
 #'
-#' Many of the default settings are specfied in the form \code{getOption("...")}
-#' to allow the user to "permanently" set them to their prefered modes by
+#' Many of the default settings are specified in the form \code{getOption("...")}
+#' to allow the user to "permanently" set them to their preferred modes by
 #' setting options in their \code{.Rprofile} file.
 #'
 #' @export
@@ -63,12 +118,12 @@
 #'     mechanisms for the \code{unitizers} (see \code{\link{get_unitizer}})
 #' }
 #' @param state character(1L) one of
-#'   \code{c("prisitine", "default", "basic", "off", "safe")}, an environment,
-#'   or a state object produced by \code{\link{state}} or \code{\link{in_pkg}};
-#'   modifies how \code{unitizer} manages aspects of session state that could
-#'   affect test evaluation, including the parent evaluation environment.  For
-#'   more details see \code{\link{unitizerState}} documentation and
-#'   \code{vignette("unitizer_reproducible_tests")}
+#'   \code{c("prisitine", "suggested", "basic", "off", "safe")}, an
+#'   environment, or a state object produced by \code{\link{state}} or
+#'   \code{\link{in_pkg}}; modifies how \code{unitizer} manages aspects of
+#'   session state that could affect test evaluation, including the parent
+#'   evaluation environment.  For more details see \code{\link{unitizerState}}
+#'   documentation and \code{vignette("unitizer_reproducible_tests")}
 #' @param pre NULL, or a character vector pointing to files and/or directories.
 #'   If a character vector, then any files referenced therein will be sourced,
 #'   and any directories referenced therein will be scanned non-recursively for
@@ -111,6 +166,8 @@
 #'   specify which type(s) of test you wish to auto accept (i.e. same as typing
 #'   \code{"Y"} at the \code{unitizer} prompt) or empty character vector to turn
 #'   off (default)
+#' @param use.diff TRUE or FALSE, whether to use diffs when there is an error,
+#'   if FALSE uses \code{\link{all.equal}} instead.
 #' @return \code{unitize} and company are intended to be used primarily for
 #'   the interactive environment and side effects.  The functions do return
 #'   summary data about test outcomes and user input as
@@ -128,7 +185,8 @@ unitize <- function(
   history=getOption("unitizer.history.file"),
   interactive.mode=interactive(),
   force.update=FALSE,
-  auto.accept=character(0L)
+  auto.accept=character(0L),
+  use.diff=getOption("unitizer.use.diff")
 ) {
   # Initial spacer, must be done in each top level call
 
@@ -145,7 +203,7 @@ unitize <- function(
       test.file.inf, list(store.id.inf), state=state,
       pre=pre, post=post, history=history,
       interactive.mode=interactive.mode,  force.update=force.update,
-      auto.accept=auto.accept, mode="unitize"
+      auto.accept=auto.accept, mode="unitize", use.diff=use.diff
     )[[1L]]
   )
 }
@@ -168,7 +226,8 @@ review <- function(store.id=NULL) {
       interactive.mode=TRUE,
       force.update=FALSE,
       auto.accept=character(0L),
-      mode="review"
+      mode="review",
+      use.diff=TRUE
     )[[1L]]
   )
 }
@@ -184,7 +243,8 @@ unitize_dir <- function(
   history=getOption("unitizer.history.file"),
   interactive.mode=interactive(),
   force.update=FALSE,
-  auto.accept=character(0L)
+  auto.accept=character(0L),
+  use.diff=getOption("unitizer.use.diff")
 ) {
   # Validations
   if(
@@ -233,6 +293,6 @@ unitize_dir <- function(
       state=state,
       pre=pre, post=post, history=history,
       interactive.mode=interactive.mode, force.update=force.update,
-      auto.accept=auto.accept, mode="unitize"
+      auto.accept=auto.accept, mode="unitize", use.diff=use.diff
   ) )
 }
