@@ -89,6 +89,7 @@ local({
     "change",
     "demo",
     "error",
+
     "exec",
     "get",
     "global",
@@ -96,30 +97,35 @@ local({
     "inpkg",
     "ischecks",
     "item",
+
     "list",
     "misc",
+
     "options",
     "parse",
     "prompt",
     "rename",
+
     "repairenvs",
     "random",
     "search",
     "section",
     "shim",
+
     "state",
     "text",
     "translate",
     "utz1",
     "utz2",
     "upgrade",
-    "zzrunlast"
+    "zzrunlast",
+    "not_a_real_test_file"
   )
-  # test.filt <- 'parse'
+  # test.filt <- 'exec'
   test.res <- if(packageVersion('testthat') > "1.0.2") {
     test_dir(
       "testthat",
-      #reporter="check",
+      # reporter="check",
       env=environment(),
       filter=test.filt,
       wrap=FALSE
